@@ -273,6 +273,14 @@ class MenuBar(QMenuBar):
             checkable=True,
             checked=cfg.pyqode_show_line_numbers
         )
+        self._action_toggle_tab_bar = self._action(
+            _(u'Show editor tabs'),
+            u'accessories-text-editor',
+            None,
+            self._toggle_show_tab_bar,
+            checkable=True,
+            checked=cfg.openseame_ide_show_tab_bar
+        )
         self._action_select_indentation_mode = self._action(
             _(u'Select indentation mode'),
             u'accessories-text-editor',
@@ -303,13 +311,23 @@ class MenuBar(QMenuBar):
             checkable=True,
             checked=cfg.pyqode_fixed_width
         )
+        self._action_toggle_code_completion = self._action(
+            _(u'Code completion'),
+            u'accessories-text-editor',
+            None,
+            self._toggle_code_completion,
+            checkable=True,
+            checked=cfg.pyqode_code_completion
+        )
         self._menu_editor.addAction(self._action_toggle_line_wrap)
         self._menu_editor.addAction(self._action_toggle_whitespaces)
         self._menu_editor.addAction(self._action_toggle_line_numbers)
+        self._menu_editor.addAction(self._action_toggle_tab_bar)
         self._menu_editor.addAction(self._action_select_indentation_mode)
         self._menu_editor.addAction(self._action_toggle_code_folding)
         self._menu_editor.addAction(self._action_toggle_right_margin)
         self._menu_editor.addAction(self._action_toggle_fixed_width)
+        self._menu_editor.addAction(self._action_toggle_code_completion)
         self._action_word_count = self._add_extension_action(
             'SpellCheck',
             menu=self._menu_editor,
@@ -400,6 +418,13 @@ class MenuBar(QMenuBar):
             fixed_width=fixed_width
         )
 
+    def _toggle_code_completion(self, code_completion):
+
+        self._ide.extension_manager.fire(
+            'pyqode_set_code_completion',
+            code_completion=code_completion
+        )
+
     def _toggle_line_wrap(self, line_wrap):
 
         self._ide.extension_manager.fire(
@@ -421,6 +446,13 @@ class MenuBar(QMenuBar):
             show_right_margin=show_right_margin
         )
 
+    def _toggle_show_tab_bar(self, show_tab_bar):
+
+        self._ide.extension_manager.fire(
+            'ide_show_tab_bar',
+            show_tab_bar=show_tab_bar
+        )
+
     def _toggle_show_whitespaces(self, show_whitespaces):
 
         self._ide.extension_manager.fire(
